@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019  Stéphane Bard <stephane.bard@gmail.com>
+# Copyright (C) 2021  Stéphane Bard <stephane.bard@gmail.com>
 #
 # This file is part of hg_delivery
 #
@@ -19,13 +19,14 @@ import os.path
 import uuid
 import sys
 import collections
+import zope.interface
+import zope.component
 
-from pygments import highlight
-from pygments.lexers import DiffLexer
-from pygments.formatters import HtmlFormatter
-from pygments.styles import get_all_styles
+from .interfaces import DVCSInterface
+from .tools import DiffWrapper
 
-styles = list(get_all_styles())
+from zope.component.factory import Factory
+from zope.component.interfaces import IFactory
 
 log = logging.getLogger(__name__)
 
@@ -123,61 +124,6 @@ def check_connections(function):
 # ------------------------------------------------------------------------------
 
 
-class DiffWrapper(object):
-    """
-    """
-    def __init__(self, raw_diff):
-        """
-        """
-        self.raw_diff = raw_diff
-
-        self.lst_files = []
-        self.dict_files = []
-        self.lst_basename_files = []
-
-        if self.raw_diff:
-            # we init content ...
-            self.lst_files = self.__get_lst_files()
-            self.lst_basename_files = [
-                os.path.basename(f_name) for f_name in self.lst_files
-            ]
-            self.dict_files = self.__get_files_to_diff()
-
-    def __get_lst_files(self):
-        """
-        """
-        # add some non capturing group for revision argument ...
-        # (just for remind !)
-        groups = re.findall(u"diff(?: -r [a-z0-9]+){1,2} (?P<file_name>.+)$",
-                            self.raw_diff, re.MULTILINE)
-        return groups
-
-    def __get_files_to_diff(self):
-        """
-        """
-        groups = self.__get_lst_files()
-        diffs_content = [
-            highlight(bloc, DiffLexer(),
-                      HtmlFormatter(cssclass=u'source', style=u'colorful'))
-            for bloc in re.split(u"\n*diff -r [a-z0-9]{8,20} [^\n]+\n",
-                                 self.raw_diff) if bloc.strip()
-        ]
-        return dict(zip(groups, diffs_content))
-
-    def __json__(self, request):
-        """
-        """
-        return {
-            u'id': self.raw_diff,
-            u'lst_files': self.lst_files,
-            u'lst_basename_files': self.lst_basename_files,
-            u'dict_files': self.dict_files
-        }
-
-
-# ------------------------------------------------------------------------------
-
-
 class NodeSsh(object):
     """
     """
@@ -446,6 +392,10 @@ class NodeSsh(object):
             # catch any, release the lock and throw again
             self.release_lock()
             raise e
+        except:
+            # catch exception without inheritance from Exception
+            self.release_lock()
+            raise Exception("Unknown exception")
 
         return {
             u'out': full_log,
@@ -506,6 +456,10 @@ class NodeSsh(object):
             # by `with statement`
             self.release_lock()
             raise e
+        except:
+            # catch exception without inheritance from Exception
+            self.release_lock()
+            raise Exception("Unknown exception")
         return result
 
     def compare_release_a_sup_equal_b(self, release_a, release_b):
@@ -533,10 +487,10 @@ class NodeSsh(object):
 
         return result
 
-
 # ------------------------------------------------------------------------------
 
 
+@zope.interface.implementer(DVCSInterface)
 class HgNode(NodeSsh):
     """
       Some node to manipulate remote hg repository
@@ -599,9 +553,9 @@ class HgNode(NodeSsh):
         if not local_project.dvcs_release:
             local_project.dvcs_release = self.get_release()
 
-        if (local_project.dvcs_release is not None
-                and self.compare_release_a_sup_equal_b(
-                    local_project.dvcs_release, '1.7.4')):
+        if (local_project.dvcs_release is not None and
+            self.compare_release_a_sup_equal_b(local_project.dvcs_release,
+                                               '1.7.4')):
             insecure = u" --insecure "
         else:
             # what ever mercurial release, even if its not mandatory
@@ -972,7 +926,7 @@ class HgNode(NodeSsh):
 
 # ------------------------------------------------------------------------------
 
-
+@zope.interface.implementer(DVCSInterface)
 class GitNode(NodeSsh):
     """
       A specific node to manipulate remote git
@@ -1003,7 +957,7 @@ class GitNode(NodeSsh):
         """
           commit 1ea7f6aa3feef3e257e3fe4fde6b6994983c6062
           Author: sbard <toto.free.fr>
-          Date:   Wed Sep 10 10:10:27 2019 +0200
+          Date:   Wed Sep 10 10:10:27 2021 +0200
 
               fix test
 
@@ -1219,7 +1173,7 @@ class GitNode(NodeSsh):
 # ------------------------------------------------------------------------------
 
 
-class NodeController(object):
+class NodeController():
     """
        control an ssh node and release the lock
        when we finish to use it
@@ -1341,7 +1295,10 @@ class PoolSsh(object):
         key_uri_node = uri
 
         if key_uri_node not in cls.nodes:
-            node = HgNode(uri, project_id, local_pkey=local_pkey)
+            node = zope.component.createObject('hg',
+                                               uri,
+                                               project_id,
+                                               local_pkey=local_pkey)
             node.lock_it()
             cls.nodes[key_uri_node] = [node]
             log.info(u"new node in pool %s" % uri)
@@ -1376,3 +1333,8 @@ class PoolSsh(object):
             _msg += ", please retry later or fix parameters"
             raise UnavailableConnexion(_msg)
         return node
+
+
+gsm = zope.component.getGlobalSiteManager()
+hg_factory = Factory(HgNode, 'hg', 'HG Node Factory', DVCSInterface)
+gsm.registerUtility(hg_factory, IFactory, 'hg')
\ No newline at end of file
