@@ -15,8 +15,7 @@ from pyramid.security import (
     forget,
     Allow,
     Everyone,
-    Authenticated,
-    unauthenticated_userid
+    Authenticated
 )
 
 from .models import (
@@ -36,7 +35,7 @@ def get_user(request):
     """
     returns user object by querying the db. If user is not found None is return
     """
-    userid = unauthenticated_userid(request)
+    userid = request.authenticated_userid
     user = None
     if userid is not None:
         user = request.dbsession.query(User).filter(
@@ -86,8 +85,8 @@ class RootFactory(object):
 
     __acl__ = [(Allow, Everyone, 'view'),
                (Allow, 'group:editors', 'edit'),
-               (Allow, 'group:editors', 'authenticated'),
-               (Allow, Authenticated, 'authenticated')]
+               (Allow, 'group:editors', 'system.Authenticated'),
+               (Allow, Authenticated, 'system.Authenticated')]
 
     def __init__(self, request):
         """
